package com.ruoyi.interfaces.mapper;

import java.util.List;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.interfaces.domain.MdDataField;

/**
 * 数据集字段Mapper接口
 * 
 * @author 朱得糠
 * @date 2025-09-04
 */
@DataSource(DataSourceType.SLAVE)
public interface MdDataFieldMapper 
{
    /**
     * 查询数据集字段
     * 
     * @param id 数据集字段主键
     * @return 数据集字段
     */
    public MdDataField selectMdDataFieldById(Long id);

    /**
     * 查询数据集字段列表
     * 
     * @param mdDataField 数据集字段
     * @return 数据集字段集合
     */
    public List<MdDataField> selectMdDataFieldList(MdDataField mdDataField);

    /**
     * 新增数据集字段
     * 
     * @param mdDataField 数据集字段
     * @return 结果
     */
    public int insertMdDataField(MdDataField mdDataField);

    /**
     * 修改数据集字段
     * 
     * @param mdDataField 数据集字段
     * @return 结果
     */
    public int updateMdDataField(MdDataField mdDataField);

    /**
     * 删除数据集字段
     * 
     * @param id 数据集字段主键
     * @return 结果
     */
    public int deleteMdDataFieldById(Long id);

    /**
     * 批量删除数据集字段
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMdDataFieldByIds(Long[] ids);

    int deleteMdDataFieldByDcCode(String dcCode);
}
